# Team

All members are assumed NREL employees, unless otherwise noted.

## Software

- Rob Hammond

## Methodology

- Aubryn Cooperman
- Rob Hammond
- Owen Roberts
- Shawn Sheng

## Leadership

- Rob Hammond
- Annika Eberle
- Matt Shields

## Former

- Alicia Key
- Aaron Barker
